@@ -4,7 +4,7 @@
 //!
 //! [`SimpleExpr`] is the expression common among select fields, where clauses and many other places.
 
-use crate::{query::*, func::*, types::*, value::*};
+use crate::{func::*, query::*, types::*, value::*};
 
 /// Helper to build a [`SimpleExpr`].
 #[derive(Debug, Clone, Default)]
@@ -18,7 +18,7 @@ pub struct Expr {
 }
 
 /// Represents a Simple Expression in SQL.
-/// 
+///
 /// [`SimpleExpr`] is a node in the expression tree and can represent identifiers, function calls,
 /// various operators and sub-queries.
 #[derive(Debug, Clone)]
@@ -52,18 +52,18 @@ impl Expr {
     }
 
     /// Express the target column without table prefix.
-    /// 
+    ///
     /// # Examples
-    /// 
+    ///
     /// ```
     /// use sea_query::{*, tests_cfg::*};
-    /// 
+    ///
     /// let query = Query::select()
     ///     .columns(vec![Char::Character, Char::SizeW, Char::SizeH])
     ///     .from(Char::Table)
     ///     .and_where(Expr::col(Char::SizeW).eq(1))
     ///     .to_owned();
-    /// 
+    ///
     /// assert_eq!(
     ///     query.to_string(MysqlQueryBuilder),
     ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE `size_w` = 1"#
@@ -77,16 +77,16 @@ impl Expr {
     ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE `size_w` = 1"#
     /// );
     /// ```
-    /// 
+    ///
     /// ```
     /// use sea_query::{*, tests_cfg::*};
-    /// 
+    ///
     /// let query = Query::select()
     ///     .columns(vec![Char::Character, Char::SizeW, Char::SizeH])
     ///     .from(Char::Table)
     ///     .and_where(Expr::col((Char::Table, Char::SizeW)).eq(1))
     ///     .to_owned();
-    /// 
+    ///
     /// assert_eq!(
     ///     query.to_string(MysqlQueryBuilder),
     ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE `character`.`size_w` = 1"#
@@ -101,23 +101,25 @@ impl Expr {
     /// );
     /// ```
     pub fn col<T>(n: T) -> Self
-        where T: IntoColumnRef {
+    where
+        T: IntoColumnRef,
+    {
         Self::new_with_left(SimpleExpr::Column(n.into_column_ref()))
     }
 
     /// Express the target column with table prefix.
-    /// 
+    ///
     /// # Examples
-    /// 
+    ///
     /// ```
     /// use sea_query::{*, tests_cfg::*};
-    /// 
+    ///
     /// let query = Query::select()
     ///     .columns(vec![Char::Character, Char::SizeW, Char::SizeH])
     ///     .from(Char::Table)
     ///     .and_where(Expr::tbl(Char::Table, Char::SizeW).eq(1))
     ///     .to_owned();
-    /// 
+    ///
     /// assert_eq!(
     ///     query.to_string(MysqlQueryBuilder),
     ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE `character`.`size_w` = 1"#
@@ -132,17 +134,20 @@ impl Expr {
     /// );
     /// ```
     pub fn tbl<T, C>(t: T, c: C) -> Self
-        where T: IntoIden, C: IntoIden {
+    where
+        T: IntoIden,
+        C: IntoIden,
+    {
         Self::col((t.into_iden(), c.into_iden()))
     }
 
     /// Express a [`Value`], returning a [`Expr`].
-    /// 
+    ///
     /// # Examples
-    /// 
+    ///
     /// ```
     /// use sea_query::{*, tests_cfg::*};
-    /// 
+    ///
     /// let query = Query::select()
     ///     .columns(vec![Char::Character, Char::SizeW, Char::SizeH])
     ///     .from(Char::Table)
@@ -150,7 +155,7 @@ impl Expr {
     ///     .and_where(Expr::val(2.5).into())
     ///     .and_where(Expr::val("3").into())
     ///     .to_owned();
-    /// 
+    ///
     /// assert_eq!(
     ///     query.to_string(MysqlQueryBuilder),
     ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE 1 AND 2.5 AND '3'"#
@@ -165,23 +170,25 @@ impl Expr {
     /// );
     /// ```
     pub fn val<V>(v: V) -> Self
-        where V: Into<Value> {
+    where
+        V: Into<Value>,
+    {
         Self::new_with_left(SimpleExpr::Value(v.into()))
     }
 
     /// Wrap a [`SimpleExpr`] and perform some operation on it.
-    /// 
+    ///
     /// # Examples
-    /// 
+    ///
     /// ```
     /// use sea_query::{*, tests_cfg::*};
-    /// 
+    ///
     /// let query = Query::select()
     ///     .columns(vec![Char::Character, Char::SizeW, Char::SizeH])
     ///     .from(Char::Table)
     ///     .and_where(Expr::expr(Expr::col(Char::SizeW).if_null(0)).gt(2))
     ///     .to_owned();
-    /// 
+    ///
     /// assert_eq!(
     ///     query.to_string(MysqlQueryBuilder),
     ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE IFNULL(`size_w`, 0) > 2"#
@@ -200,12 +207,12 @@ impl Expr {
     }
 
     /// Express a [`Value`], returning a [`SimpleExpr`].
-    /// 
+    ///
     /// # Examples
-    /// 
+    ///
     /// ```
     /// use sea_query::{*, tests_cfg::*};
-    /// 
+    ///
     /// let query = Query::select()
     ///     .columns(vec![Char::Character, Char::SizeW, Char::SizeH])
     ///     .from(Char::Table)
@@ -213,7 +220,7 @@ impl Expr {
     ///     .and_where(Expr::value(2.5).into())
     ///     .and_where(Expr::value("3").into())
     ///     .to_owned();
-    /// 
+    ///
     /// assert_eq!(
     ///     query.to_string(MysqlQueryBuilder),
     ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE 1 AND 2.5 AND '3'"#
@@ -228,23 +235,25 @@ impl Expr {
     /// );
     /// ```
     pub fn value<V>(v: V) -> SimpleExpr
-        where V: Into<Value> {
+    where
+        V: Into<Value>,
+    {
         SimpleExpr::Value(v.into())
     }
 
     /// Express any custom expression in [`&str`].
-    /// 
+    ///
     /// # Examples
-    /// 
+    ///
     /// ```
     /// use sea_query::{*, tests_cfg::*};
-    /// 
+    ///
     /// let query = Query::select()
     ///     .columns(vec![Char::Character, Char::SizeW, Char::SizeH])
     ///     .from(Char::Table)
     ///     .and_where(Expr::cust("1 = 1").into())
     ///     .to_owned();
-    /// 
+    ///
     /// assert_eq!(
     ///     query.to_string(MysqlQueryBuilder),
     ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE 1 = 1"#
@@ -263,19 +272,19 @@ impl Expr {
     }
 
     /// Express any custom expression with [`Value`]. Use this if your expression needs variables.
-    /// 
+    ///
     /// # Examples
-    /// 
+    ///
     /// ```
     /// use sea_query::{*, tests_cfg::*};
-    /// 
+    ///
     /// let query = Query::select()
     ///     .columns(vec![Char::Character, Char::SizeW, Char::SizeH])
     ///     .from(Char::Table)
     ///     .and_where(Expr::col(Char::Id).eq(1))
     ///     .and_where(Expr::cust_with_values("6 = ? * ?", vec![2, 3]).into())
     ///     .to_owned();
-    /// 
+    ///
     /// assert_eq!(
     ///     query.to_string(MysqlQueryBuilder),
     ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE `id` = 1 AND 6 = 2 * 3"#
@@ -298,19 +307,19 @@ impl Expr {
     }
 
     /// Express an equal (`=`) expression.
-    /// 
+    ///
     /// # Examples
-    /// 
+    ///
     /// ```
     /// use sea_query::{*, tests_cfg::*};
-    /// 
+    ///
     /// let query = Query::select()
     ///     .columns(vec![Char::Character, Char::SizeW, Char::SizeH])
     ///     .from(Char::Table)
     ///     .and_where(Expr::val("What!").eq("Nothing"))
     ///     .and_where(Expr::col(Char::Id).eq(1))
     ///     .to_owned();
-    /// 
+    ///
     /// assert_eq!(
     ///     query.to_string(MysqlQueryBuilder),
     ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE 'What!' = 'Nothing' AND `id` = 1"#
@@ -325,24 +334,26 @@ impl Expr {
     /// );
     /// ```
     pub fn eq<V>(self, v: V) -> SimpleExpr
-        where V: Into<Value> {
+    where
+        V: Into<Value>,
+    {
         self.bin_oper(BinOper::Equal, SimpleExpr::Value(v.into()))
     }
 
     /// Express a not equal (`<>`) expression.
-    /// 
+    ///
     /// # Examples
-    /// 
+    ///
     /// ```
     /// use sea_query::{*, tests_cfg::*};
-    /// 
+    ///
     /// let query = Query::select()
     ///     .columns(vec![Char::Character, Char::SizeW, Char::SizeH])
     ///     .from(Char::Table)
     ///     .and_where(Expr::val("Morning").ne("Good"))
     ///     .and_where(Expr::col(Char::Id).ne(1))
     ///     .to_owned();
-    /// 
+    ///
     /// assert_eq!(
     ///     query.to_string(MysqlQueryBuilder),
     ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE 'Morning' <> 'Good' AND `id` <> 1"#
@@ -357,24 +368,26 @@ impl Expr {
     /// );
     /// ```
     pub fn ne<V>(self, v: V) -> SimpleExpr
-        where V: Into<Value> {
+    where
+        V: Into<Value>,
+    {
         self.bin_oper(BinOper::NotEqual, SimpleExpr::Value(v.into()))
     }
 
     /// Express a equal expression between two table columns,
     /// you will mainly use this to relate identical value between two table columns.
-    /// 
+    ///
     /// # Examples
-    /// 
+    ///
     /// ```
     /// use sea_query::{*, tests_cfg::*};
-    /// 
+    ///
     /// let query = Query::select()
     ///     .columns(vec![Char::Character, Char::SizeW, Char::SizeH])
     ///     .from(Char::Table)
     ///     .and_where(Expr::tbl(Char::Table, Char::FontId).equals(Font::Table, Font::Id))
     ///     .to_owned();
-    /// 
+    ///
     /// assert_eq!(
     ///     query.to_string(MysqlQueryBuilder),
     ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE `character`.`font_id` = `font`.`id`"#
@@ -389,23 +402,29 @@ impl Expr {
     /// );
     /// ```
     pub fn equals<T, C>(self, t: T, c: C) -> SimpleExpr
-        where T: IntoIden, C: IntoIden {
-        self.bin_oper(BinOper::Equal, SimpleExpr::Column((t.into_iden(), c.into_iden()).into_column_ref()))
+    where
+        T: IntoIden,
+        C: IntoIden,
+    {
+        self.bin_oper(
+            BinOper::Equal,
+            SimpleExpr::Column((t.into_iden(), c.into_iden()).into_column_ref()),
+        )
     }
 
     /// Express a greater than (`>`) expression.
-    /// 
+    ///
     /// # Examples
-    /// 
+    ///
     /// ```
     /// use sea_query::{*, tests_cfg::*};
-    /// 
+    ///
     /// let query = Query::select()
     ///     .columns(vec![Char::Character, Char::SizeW, Char::SizeH])
     ///     .from(Char::Table)
     ///     .and_where(Expr::tbl(Char::Table, Char::SizeW).gt(2))
     ///     .to_owned();
-    /// 
+    ///
     /// assert_eq!(
     ///     query.to_string(MysqlQueryBuilder),
     ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE `character`.`size_w` > 2"#
@@ -420,23 +439,25 @@ impl Expr {
     /// );
     /// ```
     pub fn gt<V>(self, v: V) -> SimpleExpr
-        where V: Into<Value> {
+    where
+        V: Into<Value>,
+    {
         self.bin_oper(BinOper::GreaterThan, SimpleExpr::Value(v.into()))
     }
 
     /// Express a greater than or equal (`>=`) expression.
-    /// 
+    ///
     /// # Examples
-    /// 
+    ///
     /// ```
     /// use sea_query::{*, tests_cfg::*};
-    /// 
+    ///
     /// let query = Query::select()
     ///     .columns(vec![Char::Character, Char::SizeW, Char::SizeH])
     ///     .from(Char::Table)
     ///     .and_where(Expr::tbl(Char::Table, Char::SizeW).gte(2))
     ///     .to_owned();
-    /// 
+    ///
     /// assert_eq!(
     ///     query.to_string(MysqlQueryBuilder),
     ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE `character`.`size_w` >= 2"#
@@ -451,23 +472,25 @@ impl Expr {
     /// );
     /// ```
     pub fn gte<V>(self, v: V) -> SimpleExpr
-        where V: Into<Value> {
+    where
+        V: Into<Value>,
+    {
         self.bin_oper(BinOper::GreaterThanOrEqual, SimpleExpr::Value(v.into()))
     }
 
     /// Express a less than (`<`) expression.
-    /// 
+    ///
     /// # Examples
-    /// 
+    ///
     /// ```
     /// use sea_query::{*, tests_cfg::*};
-    /// 
+    ///
     /// let query = Query::select()
     ///     .columns(vec![Char::Character, Char::SizeW, Char::SizeH])
     ///     .from(Char::Table)
     ///     .and_where(Expr::tbl(Char::Table, Char::SizeW).lt(2))
     ///     .to_owned();
-    /// 
+    ///
     /// assert_eq!(
     ///     query.to_string(MysqlQueryBuilder),
     ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE `character`.`size_w` < 2"#
@@ -482,23 +505,25 @@ impl Expr {
     /// );
     /// ```
     pub fn lt<V>(self, v: V) -> SimpleExpr
-        where V: Into<Value> {
+    where
+        V: Into<Value>,
+    {
         self.bin_oper(BinOper::SmallerThan, SimpleExpr::Value(v.into()))
     }
 
     /// Express a less than or equal (`<=`) expression.
-    /// 
+    ///
     /// # Examples
-    /// 
+    ///
     /// ```
     /// use sea_query::{*, tests_cfg::*};
-    /// 
+    ///
     /// let query = Query::select()
     ///     .columns(vec![Char::Character, Char::SizeW, Char::SizeH])
     ///     .from(Char::Table)
     ///     .and_where(Expr::tbl(Char::Table, Char::SizeW).lte(2))
     ///     .to_owned();
-    /// 
+    ///
     /// assert_eq!(
     ///     query.to_string(MysqlQueryBuilder),
     ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE `character`.`size_w` <= 2"#
@@ -513,23 +538,25 @@ impl Expr {
     /// );
     /// ```
     pub fn lte<V>(self, v: V) -> SimpleExpr
-        where V: Into<Value> {
+    where
+        V: Into<Value>,
+    {
         self.bin_oper(BinOper::SmallerThanOrEqual, SimpleExpr::Value(v.into()))
     }
 
     /// Express an arithmetic addition operation.
-    /// 
+    ///
     /// # Examples
-    /// 
+    ///
     /// ```
     /// use sea_query::{*, tests_cfg::*};
-    /// 
+    ///
     /// let query = Query::select()
     ///     .columns(vec![Char::Character, Char::SizeW, Char::SizeH])
     ///     .from(Char::Table)
     ///     .and_where(Expr::val(1).add(1).equals(Expr::value(2)))
     ///     .to_owned();
-    /// 
+    ///
     /// assert_eq!(
     ///     query.to_string(MysqlQueryBuilder),
     ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE 1 + 1 = 2"#
@@ -545,23 +572,25 @@ impl Expr {
     /// ```
     #[allow(clippy::should_implement_trait)]
     pub fn add<V>(self, v: V) -> SimpleExpr
-        where V: Into<Value> {
+    where
+        V: Into<Value>,
+    {
         self.bin_oper(BinOper::Add, SimpleExpr::Value(v.into()))
     }
 
     /// Express an arithmetic subtraction operation.
-    /// 
+    ///
     /// # Examples
-    /// 
+    ///
     /// ```
     /// use sea_query::{*, tests_cfg::*};
-    /// 
+    ///
     /// let query = Query::select()
     ///     .columns(vec![Char::Character, Char::SizeW, Char::SizeH])
     ///     .from(Char::Table)
     ///     .and_where(Expr::val(1).sub(1).equals(Expr::value(2)))
     ///     .to_owned();
-    /// 
+    ///
     /// assert_eq!(
     ///     query.to_string(MysqlQueryBuilder),
     ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE 1 - 1 = 2"#
@@ -577,23 +606,25 @@ impl Expr {
     /// ```
     #[allow(clippy::should_implement_trait)]
     pub fn sub<V>(self, v: V) -> SimpleExpr
-        where V: Into<Value> {
+    where
+        V: Into<Value>,
+    {
         self.bin_oper(BinOper::Sub, SimpleExpr::Value(v.into()))
     }
 
     /// Express an arithmetic multiplication operation.
-    /// 
+    ///
     /// # Examples
-    /// 
+    ///
     /// ```
     /// use sea_query::{*, tests_cfg::*};
-    /// 
+    ///
     /// let query = Query::select()
     ///     .columns(vec![Char::Character, Char::SizeW, Char::SizeH])
     ///     .from(Char::Table)
     ///     .and_where(Expr::val(1).mul(1).equals(Expr::value(2)))
     ///     .to_owned();
-    /// 
+    ///
     /// assert_eq!(
     ///     query.to_string(MysqlQueryBuilder),
     ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE 1 * 1 = 2"#
@@ -609,23 +640,25 @@ impl Expr {
     /// ```
     #[allow(clippy::should_implement_trait)]
     pub fn mul<V>(self, v: V) -> SimpleExpr
-        where V: Into<Value> {
+    where
+        V: Into<Value>,
+    {
         self.bin_oper(BinOper::Mul, SimpleExpr::Value(v.into()))
     }
 
     /// Express an arithmetic division operation.
-    /// 
+    ///
     /// # Examples
-    /// 
+    ///
     /// ```
     /// use sea_query::{*, tests_cfg::*};
-    /// 
+    ///
     /// let query = Query::select()
     ///     .columns(vec![Char::Character, Char::SizeW, Char::SizeH])
     ///     .from(Char::Table)
     ///     .and_where(Expr::val(1).div(1).equals(Expr::value(2)))
     ///     .to_owned();
-    /// 
+    ///
     /// assert_eq!(
     ///     query.to_string(MysqlQueryBuilder),
     ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE 1 / 1 = 2"#
@@ -641,23 +674,25 @@ impl Expr {
     /// ```
     #[allow(clippy::should_implement_trait)]
     pub fn div<V>(self, v: V) -> SimpleExpr
-        where V: Into<Value> {
+    where
+        V: Into<Value>,
+    {
         self.bin_oper(BinOper::Div, SimpleExpr::Value(v.into()))
     }
 
     /// Express a `BETWEEN` expression.
-    /// 
+    ///
     /// # Examples
-    /// 
+    ///
     /// ```
     /// use sea_query::{*, tests_cfg::*};
-    /// 
+    ///
     /// let query = Query::select()
     ///     .columns(vec![Char::Character, Char::SizeW, Char::SizeH])
     ///     .from(Char::Table)
     ///     .and_where(Expr::tbl(Char::Table, Char::SizeW).between(1, 10))
     ///     .to_owned();
-    /// 
+    ///
     /// assert_eq!(
     ///     query.to_string(MysqlQueryBuilder),
     ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE `character`.`size_w` BETWEEN 1 AND 10"#
@@ -672,23 +707,25 @@ impl Expr {
     /// );
     /// ```
     pub fn between<V>(self, a: V, b: V) -> SimpleExpr
-        where V: Into<Value> {
+    where
+        V: Into<Value>,
+    {
         self.between_or_not_between(BinOper::Between, a, b)
     }
 
     /// Express a `NOT BETWEEN` expression.
-    /// 
+    ///
     /// # Examples
-    /// 
+    ///
     /// ```
     /// use sea_query::{*, tests_cfg::*};
-    /// 
+    ///
     /// let query = Query::select()
     ///     .columns(vec![Char::Character, Char::SizeW, Char::SizeH])
     ///     .from(Char::Table)
     ///     .and_where(Expr::tbl(Char::Table, Char::SizeW).not_between(1, 10))
     ///     .to_owned();
-    /// 
+    ///
     /// assert_eq!(
     ///     query.to_string(MysqlQueryBuilder),
     ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE `character`.`size_w` NOT BETWEEN 1 AND 10"#
@@ -703,32 +740,39 @@ impl Expr {
     /// );
     /// ```
     pub fn not_between<V>(self, a: V, b: V) -> SimpleExpr
-        where V: Into<Value> {
+    where
+        V: Into<Value>,
+    {
         self.between_or_not_between(BinOper::NotBetween, a, b)
     }
 
     fn between_or_not_between<V>(self, op: BinOper, a: V, b: V) -> SimpleExpr
-        where V: Into<Value> {
-        self.bin_oper(op, SimpleExpr::Binary(
-            Box::new(SimpleExpr::Value(a.into())),
-            BinOper::And,
-            Box::new(SimpleExpr::Value(b.into())),
-        ))
+    where
+        V: Into<Value>,
+    {
+        self.bin_oper(
+            op,
+            SimpleExpr::Binary(
+                Box::new(SimpleExpr::Value(a.into())),
+                BinOper::And,
+                Box::new(SimpleExpr::Value(b.into())),
+            ),
+        )
     }
 
     /// Express a `LIKE` expression.
-    /// 
+    ///
     /// # Examples
-    /// 
+    ///
     /// ```
     /// use sea_query::{*, tests_cfg::*};
-    /// 
+    ///
     /// let query = Query::select()
     ///     .columns(vec![Char::Character, Char::SizeW, Char::SizeH])
     ///     .from(Char::Table)
     ///     .and_where(Expr::tbl(Char::Table, Char::Character).like("Ours'%"))
     ///     .to_owned();
-    /// 
+    ///
     /// assert_eq!(
     ///     query.to_string(MysqlQueryBuilder),
     ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE `character`.`character` LIKE 'Ours\'%'"#
@@ -742,23 +786,33 @@ impl Expr {
     ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE `character`.`character` LIKE 'Ours\'%'"#
     /// );
     /// ```
-    pub fn like(self, v: &str) -> SimpleExpr  {
-        self.bin_oper(BinOper::Like, SimpleExpr::Value(Value::String(Box::new(v.to_owned()))))
+    pub fn like(self, v: &str) -> SimpleExpr {
+        self.bin_oper(
+            BinOper::Like,
+            SimpleExpr::Value(Value::String(Box::new(v.to_owned()))),
+        )
+    }
+
+    pub fn not_like(self, v: &str) -> SimpleExpr {
+        self.bin_oper(
+            BinOper::NotLike,
+            SimpleExpr::Value(Value::String(Box::new(v.to_owned()))),
+        )
     }
 
     /// Express a `IS NULL` expression.
-    /// 
+    ///
     /// # Examples
-    /// 
+    ///
     /// ```
     /// use sea_query::{*, tests_cfg::*};
-    /// 
+    ///
     /// let query = Query::select()
     ///     .columns(vec![Char::Character, Char::SizeW, Char::SizeH])
     ///     .from(Char::Table)
     ///     .and_where(Expr::tbl(Char::Table, Char::SizeW).is_null())
     ///     .to_owned();
-    /// 
+    ///
     /// assert_eq!(
     ///     query.to_string(MysqlQueryBuilder),
     ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE `character`.`size_w` IS NULL"#
@@ -778,18 +832,18 @@ impl Expr {
     }
 
     /// Express a `IS NOT NULL` expression.
-    /// 
+    ///
     /// # Examples
-    /// 
+    ///
     /// ```
     /// use sea_query::{*, tests_cfg::*};
-    /// 
+    ///
     /// let query = Query::select()
     ///     .columns(vec![Char::Character, Char::SizeW, Char::SizeH])
     ///     .from(Char::Table)
     ///     .and_where(Expr::tbl(Char::Table, Char::SizeW).is_not_null())
     ///     .to_owned();
-    /// 
+    ///
     /// assert_eq!(
     ///     query.to_string(MysqlQueryBuilder),
     ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE `character`.`size_w` IS NOT NULL"#
@@ -809,18 +863,18 @@ impl Expr {
     }
 
     /// Negates an expression with `NOT`.
-    /// 
+    ///
     /// # Examples
-    /// 
+    ///
     /// ```
     /// use sea_query::{*, tests_cfg::*};
-    /// 
+    ///
     /// let query = Query::select()
     ///     .columns(vec![Char::Character, Char::SizeW, Char::SizeH])
     ///     .from(Char::Table)
     ///     .and_where(Expr::expr(Expr::tbl(Char::Table, Char::SizeW).is_null()).not())
     ///     .to_owned();
-    /// 
+    ///
     /// assert_eq!(
     ///     query.to_string(MysqlQueryBuilder),
     ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE NOT `character`.`size_w` IS NULL"#
@@ -840,17 +894,17 @@ impl Expr {
     }
 
     /// Express a `MAX` function.
-    /// 
+    ///
     /// # Examples
-    /// 
+    ///
     /// ```
     /// use sea_query::{*, tests_cfg::*};
-    /// 
+    ///
     /// let query = Query::select()
     ///     .expr(Expr::tbl(Char::Table, Char::SizeW).max())
     ///     .from(Char::Table)
     ///     .to_owned();
-    /// 
+    ///
     /// assert_eq!(
     ///     query.to_string(MysqlQueryBuilder),
     ///     r#"SELECT MAX(`character`.`size_w`) FROM `character`"#
@@ -870,17 +924,17 @@ impl Expr {
     }
 
     /// Express a `MIN` function.
-    /// 
+    ///
     /// # Examples
-    /// 
+    ///
     /// ```
     /// use sea_query::{*, tests_cfg::*};
-    /// 
+    ///
     /// let query = Query::select()
     ///     .expr(Expr::tbl(Char::Table, Char::SizeW).min())
     ///     .from(Char::Table)
     ///     .to_owned();
-    /// 
+    ///
     /// assert_eq!(
     ///     query.to_string(MysqlQueryBuilder),
     ///     r#"SELECT MIN(`character`.`size_w`) FROM `character`"#
@@ -900,17 +954,17 @@ impl Expr {
     }
 
     /// Express a `SUM` function.
-    /// 
+    ///
     /// # Examples
-    /// 
+    ///
     /// ```
     /// use sea_query::{*, tests_cfg::*};
-    /// 
+    ///
     /// let query = Query::select()
     ///     .expr(Expr::tbl(Char::Table, Char::SizeW).sum())
     ///     .from(Char::Table)
     ///     .to_owned();
-    /// 
+    ///
     /// assert_eq!(
     ///     query.to_string(MysqlQueryBuilder),
     ///     r#"SELECT SUM(`character`.`size_w`) FROM `character`"#
@@ -930,17 +984,17 @@ impl Expr {
     }
 
     /// Express a `COUNT` function.
-    /// 
+    ///
     /// # Examples
-    /// 
+    ///
     /// ```
     /// use sea_query::{*, tests_cfg::*};
-    /// 
+    ///
     /// let query = Query::select()
     ///     .expr(Expr::tbl(Char::Table, Char::SizeW).count())
     ///     .from(Char::Table)
     ///     .to_owned();
-    /// 
+    ///
     /// assert_eq!(
     ///     query.to_string(MysqlQueryBuilder),
     ///     r#"SELECT COUNT(`character`.`size_w`) FROM `character`"#
@@ -960,17 +1014,17 @@ impl Expr {
     }
 
     /// Express a `IF NULL` function.
-    /// 
+    ///
     /// # Examples
-    /// 
+    ///
     /// ```
     /// use sea_query::{*, tests_cfg::*};
-    /// 
+    ///
     /// let query = Query::select()
     ///     .expr(Expr::tbl(Char::Table, Char::SizeW).if_null(0))
     ///     .from(Char::Table)
     ///     .to_owned();
-    /// 
+    ///
     /// assert_eq!(
     ///     query.to_string(MysqlQueryBuilder),
     ///     r#"SELECT IFNULL(`character`.`size_w`, 0) FROM `character`"#
@@ -985,24 +1039,29 @@ impl Expr {
     /// );
     /// ```
     pub fn if_null<V>(mut self, v: V) -> SimpleExpr
-        where V: Into<Value> {
+    where
+        V: Into<Value>,
+    {
         let left = self.left.take();
-        Self::func_with_args(Function::IfNull, vec![left.unwrap(), SimpleExpr::Value(v.into())])
+        Self::func_with_args(
+            Function::IfNull,
+            vec![left.unwrap(), SimpleExpr::Value(v.into())],
+        )
     }
 
     /// Express a `IN` expression.
-    /// 
+    ///
     /// # Examples
-    /// 
+    ///
     /// ```
     /// use sea_query::{*, tests_cfg::*};
-    /// 
+    ///
     /// let query = Query::select()
     ///     .columns(vec![Char::Id])
     ///     .from(Char::Table)
     ///     .and_where(Expr::tbl(Char::Table, Char::SizeW).is_in(vec![1, 2, 3]))
     ///     .to_owned();
-    /// 
+    ///
     /// assert_eq!(
     ///     query.to_string(MysqlQueryBuilder),
     ///     r#"SELECT `id` FROM `character` WHERE `character`.`size_w` IN (1, 2, 3)"#
@@ -1019,13 +1078,13 @@ impl Expr {
     /// Empty value list
     /// ```
     /// use sea_query::{*, tests_cfg::*};
-    /// 
+    ///
     /// let query = Query::select()
     ///     .columns(vec![Char::Id])
     ///     .from(Char::Table)
     ///     .and_where(Expr::tbl(Char::Table, Char::SizeW).is_in(Vec::<u8>::new()))
     ///     .to_owned();
-    /// 
+    ///
     /// assert_eq!(
     ///     query.to_string(MysqlQueryBuilder),
     ///     r#"SELECT `id` FROM `character` WHERE 1 = 2"#
@@ -1053,18 +1112,18 @@ impl Expr {
     }
 
     /// Express a `NOT IN` expression.
-    /// 
+    ///
     /// # Examples
-    /// 
+    ///
     /// ```
     /// use sea_query::{*, tests_cfg::*};
-    /// 
+    ///
     /// let query = Query::select()
     ///     .columns(vec![Char::Id])
     ///     .from(Char::Table)
     ///     .and_where(Expr::tbl(Char::Table, Char::SizeW).is_not_in(vec![1, 2, 3]))
     ///     .to_owned();
-    /// 
+    ///
     /// assert_eq!(
     ///     query.to_string(MysqlQueryBuilder),
     ///     r#"SELECT `id` FROM `character` WHERE `character`.`size_w` NOT IN (1, 2, 3)"#
@@ -1081,13 +1140,13 @@ impl Expr {
     /// Empty value list
     /// ```
     /// use sea_query::{*, tests_cfg::*};
-    /// 
+    ///
     /// let query = Query::select()
     ///     .columns(vec![Char::Id])
     ///     .from(Char::Table)
     ///     .and_where(Expr::tbl(Char::Table, Char::SizeW).is_not_in(Vec::<u8>::new()))
     ///     .to_owned();
-    /// 
+    ///
     /// assert_eq!(
     ///     query.to_string(MysqlQueryBuilder),
     ///     r#"SELECT `id` FROM `character` WHERE 1 = 1"#
@@ -1105,20 +1164,22 @@ impl Expr {
     pub fn is_not_in<V, I>(mut self, v: I) -> SimpleExpr
     where
         V: Into<Value>,
-        I: IntoIterator<Item = V>
+        I: IntoIterator<Item = V>,
     {
         self.bopr = Some(BinOper::NotIn);
-        self.right = Some(SimpleExpr::Values(v.into_iter().map(|v| v.into()).collect()));
+        self.right = Some(SimpleExpr::Values(
+            v.into_iter().map(|v| v.into()).collect(),
+        ));
         self.into()
     }
 
     /// Express a `IN` sub-query expression.
-    /// 
+    ///
     /// # Examples
-    /// 
+    ///
     /// ```
     /// use sea_query::{*, tests_cfg::*};
-    /// 
+    ///
     /// let query = Query::select()
     ///     .columns(vec![Char::Character, Char::SizeW, Char::SizeH])
     ///     .from(Char::Table)
@@ -1128,7 +1189,7 @@ impl Expr {
     ///             .take()
     ///     ))
     ///     .to_owned();
-    /// 
+    ///
     /// assert_eq!(
     ///     query.to_string(MysqlQueryBuilder),
     ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE `size_w` IN (SELECT 3 + 2 * 2)"#
@@ -1156,7 +1217,9 @@ impl Expr {
     }
 
     pub fn arg<T>(mut self, arg: T) -> SimpleExpr
-        where T: Into<SimpleExpr> {
+    where
+        T: Into<SimpleExpr>,
+    {
         self.args = vec![arg.into()];
         self.into()
     }
@@ -1197,10 +1260,7 @@ impl Expr {
 impl Into<SimpleExpr> for Expr {
     fn into(self) -> SimpleExpr {
         if let Some(uopr) = self.uopr {
-            SimpleExpr::Unary(
-                uopr,
-                Box::new(self.left.unwrap()),
-            )
+            SimpleExpr::Unary(uopr, Box::new(self.left.unwrap()))
         } else if let Some(bopr) = self.bopr {
             SimpleExpr::Binary(
                 Box::new(self.left.unwrap()),
@@ -1208,10 +1268,7 @@ impl Into<SimpleExpr> for Expr {
                 Box::new(self.right.unwrap()),
             )
         } else if let Some(func) = self.func {
-            SimpleExpr::FunctionCall(
-                func,
-                self.args
-            )
+            SimpleExpr::FunctionCall(func, self.args)
         } else if let Some(left) = self.left {
             left
         } else {
@@ -1228,19 +1285,19 @@ impl Into<SelectExpr> for Expr {
 
 impl SimpleExpr {
     /// Express a logical `AND` operation.
-    /// 
+    ///
     /// # Examples
-    /// 
+    ///
     /// ```
     /// use sea_query::{*, tests_cfg::*};
-    /// 
+    ///
     /// let query = Query::select()
     ///     .columns(vec![Char::Character, Char::SizeW, Char::SizeH])
     ///     .from(Char::Table)
     ///     .or_where(Expr::col(Char::SizeW).eq(1).and(Expr::col(Char::SizeH).eq(2)))
     ///     .or_where(Expr::col(Char::SizeW).eq(3).and(Expr::col(Char::SizeH).eq(4)))
     ///     .to_owned();
-    /// 
+    ///
     /// assert_eq!(
     ///     query.to_string(MysqlQueryBuilder),
     ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE ((`size_w` = 1) AND (`size_h` = 2)) OR ((`size_w` = 3) AND (`size_h` = 4))"#
@@ -1259,19 +1316,19 @@ impl SimpleExpr {
     }
 
     /// Express a logical `OR` operation.
-    /// 
+    ///
     /// # Examples
-    /// 
+    ///
     /// ```
     /// use sea_query::{*, tests_cfg::*};
-    /// 
+    ///
     /// let query = Query::select()
     ///     .columns(vec![Char::Character, Char::SizeW, Char::SizeH])
     ///     .from(Char::Table)
     ///     .and_where(Expr::col(Char::SizeW).eq(1).or(Expr::col(Char::SizeH).eq(2)))
     ///     .and_where(Expr::col(Char::SizeW).eq(3).or(Expr::col(Char::SizeH).eq(4)))
     ///     .to_owned();
-    /// 
+    ///
     /// assert_eq!(
     ///     query.to_string(MysqlQueryBuilder),
     ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE ((`size_w` = 1) OR (`size_h` = 2)) AND ((`size_w` = 3) OR (`size_h` = 4))"#
@@ -1290,18 +1347,18 @@ impl SimpleExpr {
     }
 
     /// Compares with another [`SimpleExpr`] for equality.
-    /// 
+    ///
     /// # Examples
-    /// 
+    ///
     /// ```
     /// use sea_query::{*, tests_cfg::*};
-    /// 
+    ///
     /// let query = Query::select()
     ///     .column(Char::Character)
     ///     .from(Char::Table)
     ///     .and_where(Expr::col(Char::SizeW).mul(2).equals(Expr::col(Char::SizeH).mul(3)))
     ///     .to_owned();
-    /// 
+    ///
     /// assert_eq!(
     ///     query.to_string(MysqlQueryBuilder),
     ///     r#"SELECT `character` FROM `character` WHERE `size_w` * 2 = `size_h` * 3"#
@@ -1316,23 +1373,25 @@ impl SimpleExpr {
     /// );
     /// ```
     pub fn equals<T>(self, right: T) -> Self
-        where T: Into<SimpleExpr> {
+    where
+        T: Into<SimpleExpr>,
+    {
         self.binary(BinOper::Equal, right.into())
     }
 
     /// Compares with another [`SimpleExpr`] for inequality.
-    /// 
+    ///
     /// # Examples
-    /// 
+    ///
     /// ```
     /// use sea_query::{*, tests_cfg::*};
-    /// 
+    ///
     /// let query = Query::select()
     ///     .column(Char::Character)
     ///     .from(Char::Table)
     ///     .and_where(Expr::col(Char::SizeW).mul(2).not_equals(Expr::col(Char::SizeH)))
     ///     .to_owned();
-    /// 
+    ///
     /// assert_eq!(
     ///     query.to_string(MysqlQueryBuilder),
     ///     r#"SELECT `character` FROM `character` WHERE `size_w` * 2 <> `size_h`"#
@@ -1347,22 +1406,24 @@ impl SimpleExpr {
     /// );
     /// ```
     pub fn not_equals<T>(self, right: T) -> Self
-        where T: Into<SimpleExpr> {
+    where
+        T: Into<SimpleExpr>,
+    {
         self.binary(BinOper::NotEqual, right.into())
     }
 
     /// Perform addition with another [`SimpleExpr`].
-    /// 
+    ///
     /// # Examples
-    /// 
+    ///
     /// ```
     /// use sea_query::{*, tests_cfg::*};
-    /// 
+    ///
     /// let query = Query::select()
     ///     .expr(Expr::col(Char::SizeW).max().add(Expr::col(Char::SizeH).max()))
     ///     .from(Char::Table)
     ///     .to_owned();
-    /// 
+    ///
     /// assert_eq!(
     ///     query.to_string(MysqlQueryBuilder),
     ///     r#"SELECT MAX(`size_w`) + MAX(`size_h`) FROM `character`"#
@@ -1378,22 +1439,24 @@ impl SimpleExpr {
     /// ```
     #[allow(clippy::should_implement_trait)]
     pub fn add<T>(self, right: T) -> Self
-        where T: Into<SimpleExpr> {
+    where
+        T: Into<SimpleExpr>,
+    {
         self.binary(BinOper::Add, right.into())
     }
 
     /// Perform subtraction with another [`SimpleExpr`].
-    /// 
+    ///
     /// # Examples
-    /// 
+    ///
     /// ```
     /// use sea_query::{*, tests_cfg::*};
-    /// 
+    ///
     /// let query = Query::select()
     ///     .expr(Expr::col(Char::SizeW).max().sub(Expr::col(Char::SizeW).min()))
     ///     .from(Char::Table)
     ///     .to_owned();
-    /// 
+    ///
     /// assert_eq!(
     ///     query.to_string(MysqlQueryBuilder),
     ///     r#"SELECT MAX(`size_w`) - MIN(`size_w`) FROM `character`"#
@@ -1409,7 +1472,9 @@ impl SimpleExpr {
     /// ```
     #[allow(clippy::should_implement_trait)]
     pub fn sub<T>(self, right: T) -> Self
-        where T: Into<SimpleExpr> {
+    where
+        T: Into<SimpleExpr>,
+    {
         self.binary(BinOper::Sub, right.into())
     }
 
@@ -1419,7 +1484,10 @@ impl SimpleExpr {
 
     #[allow(dead_code)]
     pub(crate) fn static_conditions<T, F>(self, b: bool, if_true: T, if_false: F) -> Self
-        where T: FnOnce(Self) -> Self, F: FnOnce(Self) -> Self {
+    where
+        T: FnOnce(Self) -> Self,
+        F: FnOnce(Self) -> Self,
+    {
         if b {
             if_true(self)
         } else {
@@ -1431,7 +1499,8 @@ impl SimpleExpr {
         match self {
             Self::Binary(left, oper, _) => !matches!(
                 (left.as_ref(), oper),
-                (Self::Binary(_, BinOper::And, _), BinOper::And) | (Self::Binary(_, BinOper::Or, _), BinOper::Or)
+                (Self::Binary(_, BinOper::And, _), BinOper::And)
+                    | (Self::Binary(_, BinOper::Or, _), BinOper::Or)
             ),
             _ => false,
         }
