@@ -1,12 +1,15 @@
-use crate::{ForeignKeyAction, TableForeignKey, backend::ForeignKeyBuilder, types::*, prepare::*};
+use crate::{
+    backend::SchemaBuilder, prepare::*, types::*, ForeignKeyAction, SchemaStatementBuilder,
+    TableForeignKey,
+};
 
 /// Create a foreign key constraint for an existing table. Unsupported by Sqlite
-/// 
+///
 /// # Examples
-/// 
+///
 /// ```
 /// use sea_query::{*, tests_cfg::*};
-/// 
+///
 /// let foreign_key = ForeignKey::create()
 ///     .name("FK_character_font")
 ///     .from(Char::Table, Char::FontId)
@@ -14,7 +17,7 @@ use crate::{ForeignKeyAction, TableForeignKey, backend::ForeignKeyBuilder, types
 ///     .on_delete(ForeignKeyAction::Cascade)
 ///     .on_update(ForeignKeyAction::Cascade)
 ///     .to_owned();
-/// 
+///
 /// assert_eq!(
 ///     foreign_key.to_string(MysqlQueryBuilder),
 ///     vec![
@@ -33,11 +36,11 @@ use crate::{ForeignKeyAction, TableForeignKey, backend::ForeignKeyBuilder, types
 ///     ].join(" ")
 /// );
 /// ```
-/// 
+///
 /// Composite key
 /// ```
 /// use sea_query::{*, tests_cfg::*};
-/// 
+///
 /// let foreign_key = ForeignKey::create()
 ///     .name("FK_character_glyph")
 ///     .from(Char::Table, (Char::FontId, Char::Id))
@@ -45,7 +48,7 @@ use crate::{ForeignKeyAction, TableForeignKey, backend::ForeignKeyBuilder, types
 ///     .on_delete(ForeignKeyAction::Cascade)
 ///     .on_update(ForeignKeyAction::Cascade)
 ///     .to_owned();
-/// 
+///
 /// assert_eq!(
 ///     foreign_key.to_string(MysqlQueryBuilder),
 ///     vec![
@@ -95,7 +98,10 @@ impl ForeignKeyCreateStatement {
         note = "Please use the [`ForeignKeyCreateStatement::from`] and [`ForeignKeyCreateStatement::to`]"
     )]
     pub fn table<T: 'static, R: 'static>(mut self, table: T, ref_table: R) -> Self
-        where T: Iden, R: Iden {
+    where
+        T: Iden,
+        R: Iden,
+    {
         self.foreign_key.from_tbl(table);
         self.foreign_key.to_tbl(ref_table);
         self
@@ -107,7 +113,10 @@ impl ForeignKeyCreateStatement {
         note = "Please use the [`ForeignKeyCreateStatement::from`] and [`ForeignKeyCreateStatement::to`]"
     )]
     pub fn col<T: 'static, R: 'static>(mut self, column: T, ref_column: R) -> Self
-        where T: Iden, R: Iden {
+    where
+        T: Iden,
+        R: Iden,
+    {
         self.foreign_key.from_col(column);
         self.foreign_key.to_col(ref_column);
         self
@@ -115,7 +124,10 @@ impl ForeignKeyCreateStatement {
 
     /// Set key table and columns
     pub fn from<T, C>(mut self, table: T, columns: C) -> Self
-        where T: IntoIden, C: IdenList {
+    where
+        T: IntoIden,
+        C: IdenList,
+    {
         self.foreign_key.from_tbl(table);
         for col in columns.into_iter() {
             self.foreign_key.from_col(col);
@@ -125,7 +137,10 @@ impl ForeignKeyCreateStatement {
 
     /// Set referencing table and columns
     pub fn to<T, C>(mut self, table: T, columns: C) -> Self
-        where T: IntoIden, C: IdenList {
+    where
+        T: IntoIden,
+        C: IdenList,
+    {
         self.foreign_key.to_tbl(table);
         for col in columns.into_iter() {
             self.foreign_key.to_col(col);
@@ -135,28 +150,36 @@ impl ForeignKeyCreateStatement {
 
     /// Set key table
     pub fn from_tbl<T>(mut self, table: T) -> Self
-        where T: IntoIden {
+    where
+        T: IntoIden,
+    {
         self.foreign_key.from_tbl(table);
         self
     }
 
     /// Set referencing table
     pub fn to_tbl<R>(mut self, ref_table: R) -> Self
-        where R: IntoIden {
+    where
+        R: IntoIden,
+    {
         self.foreign_key.to_tbl(ref_table);
         self
     }
 
     /// Add key column
     pub fn from_col<T>(mut self, column: T) -> Self
-        where T: IntoIden {
+    where
+        T: IntoIden,
+    {
         self.foreign_key.from_col(column);
         self
     }
 
     /// Add referencing column
     pub fn to_col<R>(mut self, ref_column: R) -> Self
-        where R: IntoIden {
+    where
+        R: IntoIden,
+    {
         self.foreign_key.to_col(ref_column);
         self
     }
@@ -172,23 +195,18 @@ impl ForeignKeyCreateStatement {
         self.foreign_key.on_update(action);
         self
     }
+}
 
-    /// Build corresponding SQL statement for certain database backend and return SQL string
-    pub fn build<T: ForeignKeyBuilder>(&self, foreign_key_builder: T) -> String {
+impl SchemaStatementBuilder for ForeignKeyCreateStatement {
+    fn build<T: SchemaBuilder>(&self, schema_builder: T) -> String {
         let mut sql = SqlWriter::new();
-        foreign_key_builder.prepare_foreign_key_create_statement(self, &mut sql);
+        schema_builder.prepare_foreign_key_create_statement(self, &mut sql);
         sql.result()
     }
 
-    /// Build corresponding SQL statement for certain database backend and return SQL string
-    pub fn build_any(&self, foreign_key_builder: &dyn ForeignKeyBuilder) -> String {
+    fn build_any(&self, schema_builder: &dyn SchemaBuilder) -> String {
         let mut sql = SqlWriter::new();
-        foreign_key_builder.prepare_foreign_key_create_statement(self, &mut sql);
+        schema_builder.prepare_foreign_key_create_statement(self, &mut sql);
         sql.result()
     }
-
-    /// Build corresponding SQL statement for certain database backend and return SQL string
-    pub fn to_string<T: ForeignKeyBuilder>(&self, foreign_key_builder: T) -> String {
-        self.build(foreign_key_builder)
-    }
-}
\ No newline at end of file
+}
