@@ -2,58 +2,59 @@
 #![deny(missing_debug_implementations)]
 
 //! <div align="center">
-//! 
+//!
 //!   <img src="https://raw.githubusercontent.com/SeaQL/sea-query/master/docs/SeaQL logo dual.png" width="320"/>
-//! 
+//!
 //!   <h1>SeaQuery</h1>
-//! 
+//!
 //!   <p>
 //!     <strong>A database agnostic runtime query builder for Rust</strong>
 //!   </p>
-//! 
+//!
 //!   [![crate](https://img.shields.io/crates/v/sea-query.svg)](https://crates.io/crates/sea-query)
 //!   [![docs](https://docs.rs/sea-query/badge.svg)](https://docs.rs/sea-query)
 //!   [![build status](https://github.com/SeaQL/sea-query/actions/workflows/rust.yml/badge.svg)](https://github.com/SeaQL/sea-query/actions/workflows/rust.yml)
-//! 
+//!
 //!   <sub>Built with ❤️ by 🌊🦀🐚</sub>
-//! 
+//!
 //! </div>
-//! 
+//!
 //! ## Introduction
-//! 
+//!
 //! SeaQuery is query builder to help you construct dynamic SQL queries in Rust.
 //! You can construct expressions, queries and schema as abstract syntax trees using an ergonomic API.
 //! We support MySQL, Postgres and SQLite behind a common interface that aligns their behaviour where appropriate.
-//! 
-//! This library is the foundation of upcoming projects: Document ORM (SeaORM) and Database Synchor (SeaHorse).
-//! 
+//!
+//! This library is the foundation of SeaORM.
+//!
 //! ## Install
-//! 
+//!
 //! ```toml
 //! # Cargo.toml
 //! [dependencies]
-//! sea-query = "*"
+//! sea-query = "^0"
 //! ```
-//! 
+//!
 //! ## Usage
-//! 
+//!
 //! Table of Content
-//! 
+//!
 //! 1. Basics
-//! 
+//!
 //!     1. [Iden](#iden)
 //!     1. [Expression](#expression)
-//!     1. [Builder](#builder)
-//! 
+//!     1. [Condition](#condition)
+//!     1. [Statement Builders](#statement-builders)
+//!
 //! 1. Query Statement
-//! 
+//!
 //!     1. [Query Select](#query-select)
 //!     1. [Query Insert](#query-insert)
 //!     1. [Query Update](#query-update)
 //!     1. [Query Delete](#query-delete)
-//! 
-//! 1. Table Statement
-//! 
+//!
+//! 1. Schema Statement
+//!
 //!     1. [Table Create](#table-create)
 //!     1. [Table Alter](#table-alter)
 //!     1. [Table Drop](#table-drop)
@@ -63,126 +64,224 @@
 //!     1. [Foreign Key Drop](#foreign-key-drop)
 //!     1. [Index Create](#index-create)
 //!     1. [Index Drop](#index-drop)
+//!
+//! ### Motivation
+//!
+//! Why would you want to use a dynamic query builder?
 //! 
-//! ### Drivers
+//! 1. Parameter bindings
+//!
+//! One of the headaches if you are using raw SQL is parameter binding, where `IN` clauses are not very
+//! friendly.
 //! 
-//! We provide integration for [SQLx](https://crates.io/crates/sqlx), 
+//! ```
+//! # use sea_query::{*, tests_cfg::*};
+//! assert_eq!(
+//!     Query::select()
+//!         .column(Glyph::Image)
+//!         .from(Glyph::Table)
+//!         .and_where(Expr::col(Glyph::Id).is_in(vec![1, 2, 3]))
+//!         .build(PostgresQueryBuilder),
+//!     (r#"SELECT "image" FROM "glyph" WHERE "id" IN ($1, $2, $3)"#.to_owned(),
+//!      Values(vec![Value::Int(1), Value::Int(2), Value::Int(3)]))
+//! );
+//! ```
+//!
+//! 2. Dynamic query
+//!
+//! If you need to construct the query at runtime based on user inputs, then you can:
+//!
+//! ```
+//! # use sea_query::{*, tests_cfg::*};
+//! Query::select()
+//!     .column(Char::Character)
+//!     .from(Char::Table)
+//!     .conditions(
+//!         // some runtime condition
+//!         true,
+//!         // if condition is true then add the following condition
+//!         |q| { q.and_where(Expr::col(Char::Id).eq(1)); },
+//!         // otherwise leave it as is
+//!         |q| { }
+//!     );
+//! ```
+//!
+//! ### Integration
+//!
+//! We provide integration for [SQLx](https://crates.io/crates/sqlx),
 //! [postgres](https://crates.io/crates/postgres) and [rusqlite](https://crates.io/crates/rusqlite).
 //! See [examples](https://github.com/SeaQL/sea-query/blob/master/examples) for usage.
-//! 
+//!
 //! ### Iden
-//! 
+//!
 //! `Iden` is a trait for identifiers used in any query statement.
-//! 
-//! Commonly implemented by Enum where each Enum represent a table found in a database,
+//!
+//! Commonly implemented by Enum where each Enum represents a table found in a database,
 //! and its variants include table name and column name.
-//! 
-//! [`Iden::unquoted()`] must be implemented to provide a mapping between Enum variant and its corresponding string value.
-//! 
+//!
+//! [`Iden::unquoted()`] must be implemented to provide a mapping between Enum variants and its 
+//! corresponding string value.
+//!
 //! ```rust
-//! use sea_query::{*, tests_cfg::*};
-//! 
+//! use sea_query::{*};
+//!
 //! // For example Character table with column id, character, font_size...
 //! pub enum Character {
 //!     Table,
 //!     Id,
-//!     Character,
-//!     FontSize,
-//!     SizeW,
-//!     SizeH,
 //!     FontId,
+//!     FontSize,
 //! }
-//! 
+//!
 //! // Mapping between Enum variant and its corresponding string value
 //! impl Iden for Character {
-//!     fn unquoted(&self, s: &mut dyn FmtWrite) {
+//!     fn unquoted(&self, s: &mut dyn std::fmt::Write) {
 //!         write!(s, "{}", match self {
 //!             Self::Table => "character",
 //!             Self::Id => "id",
-//!             Self::Character => "character",
-//!             Self::FontSize => "font_size",
-//!             Self::SizeW => "size_w",
-//!             Self::SizeH => "size_h",
 //!             Self::FontId => "font_id",
+//!             Self::FontSize => "font_size",
 //!         }).unwrap();
 //!     }
 //! }
 //! ```
-//! 
+//!
 //! If you're okay with running another procedural macro, you can activate
 //! the `derive` feature on the crate to save you some boilerplate.
-//! For more information, look at 
+//! For more usage information, look at
 //! [the derive example](https://github.com/SeaQL/sea-query/blob/master/examples/derive.rs).
-//! 
+//!
 //! ```rust
 //! # #[cfg(feature = "derive")]
 //! use sea_query::Iden;
-//! 
+//!
 //! // This will implement Iden exactly as shown above
-//! # #[cfg(feature = "derive")]
 //! #[derive(Iden)]
-//! pub enum Character {
-//!     Table,
-//!     Id,
-//!     Character,
-//!     FontSize,
-//!     SizeW,
-//!     SizeH,
-//!     FontId,
-//! }
+//! enum Character { Table }
+//! assert_eq!(Character::Table.to_string(), "character");
+//!
+//! // You can also derive a unit struct
+//! #[derive(Iden)]
+//! struct Glyph;
+//! assert_eq!(Glyph.to_string(), "glyph");
 //! ```
-//! 
+//!
 //! ### Expression
-//! 
+//!
 //! Use [`Expr`] to construct select, join, where and having expression in query.
-//! 
+//!
 //! ```rust
-//! use sea_query::{*, tests_cfg::*};
-//! 
+//! # use sea_query::{*, tests_cfg::*};
 //! assert_eq!(
 //!     Query::select()
 //!         .column(Char::Character)
 //!         .from(Char::Table)
-//!         .left_join(Font::Table, Expr::tbl(Char::Table, Char::FontId).equals(Font::Table, Font::Id))
 //!         .and_where(
 //!             Expr::expr(Expr::col(Char::SizeW).add(1)).mul(2)
 //!                 .equals(Expr::expr(Expr::col(Char::SizeH).div(2)).sub(1))
 //!         )
 //!         .and_where(Expr::col(Char::SizeW).in_subquery(
 //!             Query::select()
-//!                 .expr(Expr::cust("3 + 2 * 2"))
+//!                 .expr(Expr::cust_with_values("ln(? ^ ?)", vec![2.4, 1.2]))
 //!                 .take()
 //!         ))
-//!         .or_where(Expr::col(Char::Character).like("D").and(Expr::col(Char::Character).like("E")))
-//!         .to_string(MysqlQueryBuilder),
-//!     vec![
-//!         "SELECT `character` FROM `character`",
-//!         "LEFT JOIN `font` ON `character`.`font_id` = `font`.`id`",
-//!         "WHERE ((`size_w` + 1) * 2 = (`size_h` / 2) - 1)",
-//!             "AND `size_w` IN (SELECT 3 + 2 * 2)",
-//!             "OR ((`character` LIKE 'D') AND (`character` LIKE 'E'))",
+//!         .and_where(Expr::col(Char::Character).like("D").and(Expr::col(Char::Character).like("E")))
+//!         .to_string(PostgresQueryBuilder),
+//!     [
+//!         r#"SELECT "character" FROM "character""#,
+//!         r#"WHERE (("size_w" + 1) * 2 = ("size_h" / 2) - 1)"#,
+//!         r#"AND "size_w" IN (SELECT ln(2.4 ^ 1.2))"#,
+//!         r#"AND (("character" LIKE 'D') AND ("character" LIKE 'E'))"#,
 //!     ].join(" ")
 //! );
 //! ```
-//! 
-//! ### Builder
-//! 
-//! All the query statements and table statements support the following ways to build database specific SQL statement:
-//! 
-//! 1. `build(&self, query_builder: T) -> (String, Values)`  
-//!     Build a SQL statement as string and parameters as a vector of values, see [here](https://docs.rs/sea-query/*/sea_query/query/struct.SelectStatement.html#method.build) for example.
-//! 
-//! 1. `build_collect(&self, query_builder: T, collector: &mut dyn FnMut(Value)) -> String`  
-//!     Build a SQL statement as string and collect paramaters (usually for binding to binary protocol), see [here](https://docs.rs/sea-query/*/sea_query/query/struct.SelectStatement.html#method.build_collect) for example.
-//! 
-//! 1. `to_string(&self, query_builder: T) -> String`  
-//!     Build a SQL statement as string with parameters injected, see [here](https://docs.rs/sea-query/*/sea_query/query/struct.SelectStatement.html#method.to_string) for example.
-//! 
-//! ### Query Select
-//! 
+//!
+//! ### Condition
+//!
+//! If you have complex conditions to express, you can use the [`Condition`] builder,
+//! usable for [`ConditionalStatement::cond_where`] and [`SelectStatement::cond_having`].
+//!
+//! ```
+//! # use sea_query::{*, tests_cfg::*};
+//! assert_eq!(
+//!     Query::select()
+//!         .column(Glyph::Id)
+//!         .from(Glyph::Table)
+//!         .cond_where(
+//!             Cond::any()
+//!             .add(
+//!                 Cond::all()
+//!                 .add(Expr::col(Glyph::Aspect).is_null())
+//!                 .add(Expr::col(Glyph::Image).is_null())
+//!             )
+//!             .add(
+//!                 Cond::all()
+//!                 .add(Expr::col(Glyph::Aspect).is_in(vec![3, 4]))
+//!                 .add(Expr::col(Glyph::Image).like("A%"))
+//!             )
+//!         )
+//!         .to_string(PostgresQueryBuilder),
+//!     [
+//!         r#"SELECT "id" FROM "glyph""#,
+//!         r#"WHERE"#,
+//!         r#"("aspect" IS NULL AND "image" IS NULL)"#,
+//!         r#"OR"#,
+//!         r#"("aspect" IN (3, 4) AND "image" LIKE 'A%')"#,
+//!     ].join(" ")
+//! );
+//! ```
+//!
+//! There is also the [`any!`] and [`all!`] macro at your convenience:
+//!
+//! ```
+//! # use sea_query::{*, tests_cfg::*};
+//! Query::select()
+//!     .cond_where(
+//!         any![
+//!             Expr::col(Glyph::Aspect).is_in(vec![3, 4]),
+//!             all![
+//!                 Expr::col(Glyph::Aspect).is_null(),
+//!                 Expr::col(Glyph::Image).like("A%")
+//!             ]
+//!         ]
+//!     );
+//! ```
+//!
+//! ### Statement Builders
+//!
+//! Statements are divided into 2 categories: Query and Schema, and to be serialized into SQL
+//! with [`QueryStatementBuilder`] and [`SchemaStatementBuilder`] respectively.
+//!
+//! Schema statement has the following interface:
+//!
 //! ```rust
-//! use sea_query::{*, tests_cfg::*};
-//! 
+//! # use sea_query::{*};
+//! # trait ExampleSchemaBuilder {
+//! fn build<T: SchemaBuilder>(&self, schema_builder: T) -> String;
+//! # }
+//! ```
+//!
+//! Query statement has the following interfaces:
+//!
+//! ```rust
+//! # use sea_query::{*};
+//! # trait ExampleQueryBuilder {
+//! fn build<T: QueryBuilder>(&self, query_builder: T) -> (String, Values);
+//!
+//! fn to_string<T: QueryBuilder>(&self, query_builder: T) -> String;
+//! # }
+//! ```
+//!
+//! `build` builds a SQL statement as string and parameters to be passed to the database driver
+//! through the binary protocol. This is the preferred way as it has less overhead and is more secure.
+//!
+//! `to_string` builds a SQL statement as string with parameters injected. This is good for testing
+//! and debugging.
+//!
+//! ### Query Select
+//!
+//! ```rust
+//! # use sea_query::{*, tests_cfg::*};
 //! let query = Query::select()
 //!     .column(Char::Character)
 //!     .column((Font::Table, Font::Name))
@@ -191,7 +290,7 @@
 //!     .and_where(Expr::col(Char::SizeW).is_in(vec![3, 4]))
 //!     .and_where(Expr::col(Char::Character).like("A%"))
 //!     .to_owned();
-//! 
+//!
 //! assert_eq!(
 //!     query.to_string(MysqlQueryBuilder),
 //!     r#"SELECT `character`, `font`.`name` FROM `character` LEFT JOIN `font` ON `character`.`font_id` = `font`.`id` WHERE `size_w` IN (3, 4) AND `character` LIKE 'A%'"#
@@ -205,12 +304,11 @@
 //!     r#"SELECT `character`, `font`.`name` FROM `character` LEFT JOIN `font` ON `character`.`font_id` = `font`.`id` WHERE `size_w` IN (3, 4) AND `character` LIKE 'A%'"#
 //! );
 //! ```
-//! 
+//!
 //! ### Query Insert
-//! 
+//!
 //! ```rust
-//! use sea_query::{*, tests_cfg::*};
-//! 
+//! # use sea_query::{*, tests_cfg::*};
 //! let query = Query::insert()
 //!     .into_table(Glyph::Table)
 //!     .columns(vec![
@@ -226,7 +324,7 @@
 //!         "123".into(),
 //!     ])
 //!     .to_owned();
-//! 
+//!
 //! assert_eq!(
 //!     query.to_string(MysqlQueryBuilder),
 //!     r#"INSERT INTO `glyph` (`aspect`, `image`) VALUES (5.15, '12A'), (4.21, '123')"#
@@ -240,12 +338,11 @@
 //!     r#"INSERT INTO `glyph` (`aspect`, `image`) VALUES (5.15, '12A'), (4.21, '123')"#
 //! );
 //! ```
-//! 
+//!
 //! ### Query Update
-//! 
+//!
 //! ```rust
-//! use sea_query::{*, tests_cfg::*};
-//! 
+//! # use sea_query::{*, tests_cfg::*};
 //! let query = Query::update()
 //!     .table(Glyph::Table)
 //!     .values(vec![
@@ -254,7 +351,7 @@
 //!     ])
 //!     .and_where(Expr::col(Glyph::Id).eq(1))
 //!     .to_owned();
-//! 
+//!
 //! assert_eq!(
 //!     query.to_string(MysqlQueryBuilder),
 //!     r#"UPDATE `glyph` SET `aspect` = 1.23, `image` = '123' WHERE `id` = 1"#
@@ -268,37 +365,38 @@
 //!     r#"UPDATE `glyph` SET `aspect` = 1.23, `image` = '123' WHERE `id` = 1"#
 //! );
 //! ```
-//! 
+//!
 //! ### Query Delete
-//! 
+//!
 //! ```rust
-//! use sea_query::{*, tests_cfg::*};
-//! 
+//! # use sea_query::{*, tests_cfg::*};
 //! let query = Query::delete()
 //!     .from_table(Glyph::Table)
-//!     .or_where(Expr::col(Glyph::Id).lt(1))
-//!     .or_where(Expr::col(Glyph::Id).gt(10))
+//!     .cond_where(
+//!         Cond::any()
+//!             .add(Expr::col(Glyph::Id).lt(1))
+//!             .add(Expr::col(Glyph::Id).gt(10))
+//!     )
 //!     .to_owned();
-//! 
+//!
 //! assert_eq!(
 //!     query.to_string(MysqlQueryBuilder),
-//!     r#"DELETE FROM `glyph` WHERE (`id` < 1) OR (`id` > 10)"#
+//!     r#"DELETE FROM `glyph` WHERE `id` < 1 OR `id` > 10"#
 //! );
 //! assert_eq!(
 //!     query.to_string(PostgresQueryBuilder),
-//!     r#"DELETE FROM "glyph" WHERE ("id" < 1) OR ("id" > 10)"#
+//!     r#"DELETE FROM "glyph" WHERE "id" < 1 OR "id" > 10"#
 //! );
 //! assert_eq!(
 //!     query.to_string(SqliteQueryBuilder),
-//!     r#"DELETE FROM `glyph` WHERE (`id` < 1) OR (`id` > 10)"#
+//!     r#"DELETE FROM `glyph` WHERE `id` < 1 OR `id` > 10"#
 //! );
 //! ```
-//! 
+//!
 //! ### Table Create
-//! 
+//!
 //! ```rust
-//! use sea_query::{*, tests_cfg::*};
-//! 
+//! # use sea_query::{*, tests_cfg::*};
 //! let table = Table::create()
 //!     .table(Char::Table)
 //!     .if_not_exists()
@@ -317,7 +415,7 @@
 //!             .on_update(ForeignKeyAction::Cascade)
 //!     )
 //!     .to_owned();
-//! 
+//!
 //! assert_eq!(
 //!     table.to_string(MysqlQueryBuilder),
 //!     vec![
@@ -365,17 +463,16 @@
 //!     ].join(" ")
 //! );
 //! ```
-//! 
+//!
 //! ### Table Alter
-//! 
+//!
 //! ```rust
-//! use sea_query::{*, tests_cfg::*};
-//! 
+//! # use sea_query::{*, tests_cfg::*};
 //! let table = Table::alter()
 //!     .table(Font::Table)
 //!     .add_column(ColumnDef::new(Alias::new("new_col")).integer().not_null().default(100))
 //!     .to_owned();
-//! 
+//!
 //! assert_eq!(
 //!     table.to_string(MysqlQueryBuilder),
 //!     r#"ALTER TABLE `font` ADD COLUMN `new_col` int NOT NULL DEFAULT 100"#
@@ -389,17 +486,16 @@
 //!     r#"ALTER TABLE `font` ADD COLUMN `new_col` integer NOT NULL DEFAULT 100"#,
 //! );
 //! ```
-//! 
+//!
 //! ### Table Drop
-//! 
+//!
 //! ```rust
-//! use sea_query::{*, tests_cfg::*};
-//! 
+//! # use sea_query::{*, tests_cfg::*};
 //! let table = Table::drop()
 //!     .table(Glyph::Table)
 //!     .table(Char::Table)
 //!     .to_owned();
-//! 
+//!
 //! assert_eq!(
 //!     table.to_string(MysqlQueryBuilder),
 //!     r#"DROP TABLE `glyph`, `character`"#
@@ -413,16 +509,15 @@
 //!     r#"DROP TABLE `glyph`, `character`"#
 //! );
 //! ```
-//! 
+//!
 //! ### Table Rename
-//! 
+//!
 //! ```rust
-//! use sea_query::{*, tests_cfg::*};
-//! 
+//! # use sea_query::{*, tests_cfg::*};
 //! let table = Table::rename()
 //!     .table(Font::Table, Alias::new("font_new"))
 //!     .to_owned();
-//! 
+//!
 //! assert_eq!(
 //!     table.to_string(MysqlQueryBuilder),
 //!     r#"RENAME TABLE `font` TO `font_new`"#
@@ -436,16 +531,15 @@
 //!     r#"ALTER TABLE `font` RENAME TO `font_new`"#
 //! );
 //! ```
-//! 
+//!
 //! ### Table Truncate
-//! 
+//!
 //! ```rust
-//! use sea_query::{*, tests_cfg::*};
-//! 
+//! # use sea_query::{*, tests_cfg::*};
 //! let table = Table::truncate()
 //!     .table(Font::Table)
 //!     .to_owned();
-//! 
+//!
 //! assert_eq!(
 //!     table.to_string(MysqlQueryBuilder),
 //!     r#"TRUNCATE TABLE `font`"#
@@ -459,12 +553,11 @@
 //!     r#"TRUNCATE TABLE `font`"#
 //! );
 //! ```
-//! 
+//!
 //! ### Foreign Key Create
-//! 
+//!
 //! ```rust
-//! use sea_query::{*, tests_cfg::*};
-//! 
+//! # use sea_query::{*, tests_cfg::*};
 //! let foreign_key = ForeignKey::create()
 //!     .name("FK_character_font")
 //!     .from(Char::Table, Char::FontId)
@@ -472,7 +565,7 @@
 //!     .on_delete(ForeignKeyAction::Cascade)
 //!     .on_update(ForeignKeyAction::Cascade)
 //!     .to_owned();
-//! 
+//!
 //! assert_eq!(
 //!     foreign_key.to_string(MysqlQueryBuilder),
 //!     vec![
@@ -492,17 +585,16 @@
 //! );
 //! // Sqlite does not support modification of foreign key constraints to existing tables
 //! ```
-//! 
+//!
 //! ### Foreign Key Drop
-//! 
+//!
 //! ```rust
-//! use sea_query::{*, tests_cfg::*};
-//! 
+//! # use sea_query::{*, tests_cfg::*};
 //! let foreign_key = ForeignKey::drop()
 //!     .name("FK_character_font")
 //!     .table(Char::Table)
 //!     .to_owned();
-//! 
+//!
 //! assert_eq!(
 //!     foreign_key.to_string(MysqlQueryBuilder),
 //!     r#"ALTER TABLE `character` DROP FOREIGN KEY `FK_character_font`"#
@@ -513,18 +605,17 @@
 //! );
 //! // Sqlite does not support modification of foreign key constraints to existing tables
 //! ```
-//! 
+//!
 //! ### Index Create
-//! 
+//!
 //! ```rust
-//! use sea_query::{*, tests_cfg::*};
-//! 
+//! # use sea_query::{*, tests_cfg::*};
 //! let index = Index::create()
 //!     .name("idx-glyph-aspect")
 //!     .table(Glyph::Table)
 //!     .col(Glyph::Aspect)
 //!     .to_owned();
-//! 
+//!
 //! assert_eq!(
 //!     index.to_string(MysqlQueryBuilder),
 //!     r#"CREATE INDEX `idx-glyph-aspect` ON `glyph` (`aspect`)"#
@@ -538,17 +629,16 @@
 //!     r#"CREATE INDEX `idx-glyph-aspect` ON `glyph` (`aspect`)"#
 //! );
 //! ```
-//! 
+//!
 //! ### Index Drop
-//! 
+//!
 //! ```rust
-//! use sea_query::{*, tests_cfg::*};
-//! 
+//! # use sea_query::{*, tests_cfg::*};
 //! let index = Index::drop()
 //!     .name("idx-glyph-aspect")
 //!     .table(Glyph::Table)
 //!     .to_owned();
-//! 
+//!
 //! assert_eq!(
 //!     index.to_string(MysqlQueryBuilder),
 //!     r#"DROP INDEX `idx-glyph-aspect` ON `glyph`"#
@@ -565,16 +655,17 @@
 
 pub mod backend;
 pub mod driver;
-pub mod extension;
-pub mod foreign_key;
-pub mod index;
-pub mod query;
-pub mod table;
 pub mod error;
 pub mod expr;
+pub mod extension;
+pub mod foreign_key;
 pub mod func;
+pub mod index;
 pub mod prepare;
+pub mod query;
 pub mod schema;
+mod shim;
+pub mod table;
 pub mod tests_cfg;
 pub mod token;
 pub mod types;
@@ -592,10 +683,11 @@ pub use expr::*;
 pub use func::*;
 pub use prepare::*;
 pub use schema::*;
+//pub use shim::*;
 //pub use tests_cfg::*;
 pub use token::*;
 pub use types::*;
 pub use value::*;
 
 #[cfg(feature = "derive")]
-pub use sea_query_derive::Iden;
\ No newline at end of file
+pub use sea_query_derive::Iden;
